TransactionStarted

Enum TransactionStarted 

pub enum TransactionStarted {}
Type-state marker for a Transaction in the started state.

Started transactions may have entries added to modify properties, may be reset, and may be committed.