Module error

Module error 

Error types used throughout scuffle.

Re-exports

pub use crate::isolated::IsolatedConfigdRefreshError;

Structs

HandleCreateError
Error creating a new entity handle.
ScfEntityDescriptionErrorDisplay
Newtype wrapper for displaying ScfEntityDescriptions.
TransactionCommitError
Error committing a property group transaction.
TransactionPropertyError
Error performing an operation on a property within a property group transaction.

Enums

InstanceFromEnvError
Error getting a handle to the instance of the currently-running service instance.
InstanceFromFmriError
Error getting an instance handle via its FMRI.
InstanceOp
Kind of instance operation performed via SMF.
InstanceOpError
Error performing an SMF operation on an instance.
InstanceSmfStateError
Error getting the SMF state of an instance.
IterError
Error iterating entities.
IterErrorKind
Specific ways libscf iteration can fail.
LibscfError
Mapping of libscf error codes.
LookupError
Error looking up an entity within a parent.
PropertyGroupAddError
Error adding a property group to a service or instance.
PropertyGroupDeleteError
Error deleting a property group from a service or instance.
PropertyGroupKind
Whether a property group is direct-attached or from a composed view.
PropertyGroupTypeError
Error getting a property group’s type from libscf.
PropertyGroupUpdateError
Error from PropertyGroup::update().
ScfEntity
Name of a libscf entity.
ScfEntityDescription
Description of a libscf entity.
ScfError
Error constructing the top-level libscf handle.
ScfStringError
Error getting string values from libscf.
ScopeError
Error looking up the local scope.
ServiceRefreshAllError
Error refreshing all instances of a service.
SingleValueError
Error getting the sole value of a property.
TransactionBuildError
Error building a property group transaction.
TransactionOp
Kind of transaction operation to modify a property group.
ValueGetError
Error getting a libscf value.
ValueSetError
Error setting a libscf value.

Traits

ToEntityDescription
Trait for converting an SCF entity into its description.