pub enum Value {
}Expand description
Owned representation of a libscf value.
Most variants of Value map directly to a libscf type of a similar name;
e.g., Value::Bool(_) maps to scf_type_t::SCF_TYPE_BOOLEAN. For IP
addresses, libscf treats prefixes as optional. This type has separate Ip
and IpNet values of each address family; both the Ip and IpNet for
each family map down to a single libscf type (e.g., Value::NetAddrV4(_)
and Value::NetV4(_) both map to scf_type_t::SCF_TYPE_NET_ADDR_V4.
Variants
Bool(bool)
Count(u64)
Integer(i64)
Time(DateTime<Utc>)
AString(String)
Opaque(Vec<u8>)
UString(String)
Uri(String)
Fmri(String)
Host(String)
Hostname(String)
NetAddrV4(Ipv4Addr)
NetV4(Ipv4Net)
NetAddrV6(Ipv6Addr)
NetV6(Ipv6Net)
NetAddr(IpAddr)
Net(IpNet)
Implementations
Sourceimpl Value
impl Value
Sourcepub fn as_value_ref(&self) -> ValueRef<'_>
pub fn as_value_ref(&self) -> ValueRef<'_>
Convert this value to a borrowed ValueRef.
Sourcepub fn display_smf(&self) -> ValueDisplaySmf<'_>
pub fn display_smf(&self) -> ValueDisplaySmf<'_>
Returns a displayable type that formats values consistently with how SMF
would display them as strings (e.g., Opaque values are hex-encoded;
Time values are {seconds}.{nanoseconds}).