Error types used throughout scuffle.
Re-exports
pub use crate::isolated::IsolatedConfigdRefreshError;
Structs
- Handle
Create Error - Error creating a new entity handle.
- ScfEntity
Description Error Display - Newtype wrapper for displaying
ScfEntityDescriptions. - Transaction
Commit Error - Error committing a property group transaction.
- Transaction
Property Error - Error performing an operation on a property within a property group transaction.
Enums
- Instance
From EnvError - Error getting a handle to the instance of the currently-running service instance.
- Instance
From Fmri Error - Error getting an instance handle via its FMRI.
- Instance
Op - Kind of instance operation performed via SMF.
- Instance
OpError - Error performing an SMF operation on an instance.
- Instance
SmfState Error - Error getting the SMF state of an instance.
- Iter
Error - Error iterating entities.
- Iter
Error Kind - Specific ways
libscfiteration can fail. - Libscf
Error - Mapping of
libscferror codes. - Lookup
Error - Error looking up an entity within a parent.
- Property
Group AddError - Error adding a property group to a service or instance.
- Property
Group Delete Error - Error deleting a property group from a service or instance.
- Property
Group Kind - Whether a property group is direct-attached or from a composed view.
- Property
Group Type Error - Error getting a property group’s type from
libscf. - Property
Group Update Error - Error from
PropertyGroup::update(). - ScfEntity
- Name of a
libscfentity. - ScfEntity
Description - Description of a
libscfentity. - ScfError
- Error constructing the top-level
libscfhandle. - ScfString
Error - Error getting string values from
libscf. - Scope
Error - Error looking up the local scope.
- Service
Refresh AllError - Error refreshing all instances of a service.
- Single
Value Error - Error getting the sole value of a property.
- Transaction
Build Error - Error building a property group transaction.
- Transaction
Op - Kind of transaction operation to modify a property group.
- Value
GetError - Error getting a
libscfvalue. - Value
SetError - Error setting a
libscfvalue.
Traits
- ToEntity
Description - Trait for converting an SCF entity into its description.