pub enum PropertyGroupKind {
DirectAttached,
InstanceComposed,
SnapshotComposed {
snapshot_name: Box<str>,
},
}Expand description
Whether a property group is direct-attached or from a composed view.
Variants
DirectAttached
The property group is directly attached to a service or instance.
InstanceComposed
The property group is from the composed view of an instance.
SnapshotComposed
The property group is from the composed view of a snapshot.